<?php

global $defaults;

/**
* Prints HTML with meta information for the Tags
*/
if ( ! function_exists( 'minimal_post_tag' ) ) :
    function minimal_post_tag() {
        // Hide category and tag text for pages.
        if ( get_post_type() === 'post') {
            /* translators: used between list items, there is a space after the comma */
            $tags_list = get_the_tag_list();
            if ( $tags_list && ! is_wp_error( $tags_list ) ) {
                echo '<span class="meta meta-tag">' . wp_kses_post( $tags_list ) . '</span>';
            }
        }
    }
endif;

/**
* Prints Post published date
*/
if ( ! function_exists( 'minimal_published_on' ) ) :
    function minimal_published_on() { ?>
        <span class="meta post-meta__time">
            <time datetime="<?php echo get_the_date(get_option('date_format')); ?>" pubdate>
            <?php echo get_the_date(get_option('date_format'));?>
            </time>
        </span>

    <?php }
endif;

/**
* Prints HTML with meta information for the current post-date/time and author.
*/
if ( ! function_exists( 'minimal_post_author' ) ) :
function minimal_post_author() { ?>

  <p class="meta post-meta__author">
    <span class="vcard author author_name">
    <span class="fn">
      <a href="<?php echo esc_url(get_author_posts_url( get_the_author_meta( 'ID' )));?>" class="post-meta__author__link">
        <?php the_author(); ?>
      </a>
    </span>
    </span>
  </p>

<?php
}
endif;

/**
* Image of Article or Post Author
*/
if ( ! function_exists( 'minimal_post_author_image' ) ) :
function minimal_post_author_image(){

    global $post;
    $author_id=$post->post_author; ?>

    <div class="meta post__author-box">

      <a class="post__author__photo"><?php echo get_avatar($author_id, '65');?></a>
      <span class="post__author__details">
        <p>by <a href="<?php echo esc_url(get_author_posts_url( get_the_author_meta( 'ID' )));?>"><?php the_author();?></a></p>
      </span>

    </div>
<?php }
endif;


/**
* Image of Article or Post Author
*/
if ( ! function_exists( 'minimal_post_author_image_only' ) ) :
function minimal_post_author_image_only(){

    global $post;
    $author_id = $post->post_author;

    echo get_avatar($author_id, '65');
 }

endif;


/**
* Article or Post summary word count
*/
if ( ! function_exists( 'minimal_post_summary_word_count' ) ) :
    function minimal_post_summary_word_count( $length ) {
        return 20;
    }
endif;

/**
* If it doesn't have a featured image, set a default image as Post thumbnail
*/
function minimal_post_thumbnail(){
  global $defaults;
    if ( has_post_thumbnail() ) {
        the_post_thumbnail('minimal-mag-magazine-thumb', array('class' => 'img-respponsive blog__post__image'));
    }else{
        $featured_image = get_template_directory_uri() . '/images/post-image.png';?>
            <img src="<?php echo esc_url($featured_image);?>" class ="img-respponsive blog__post__image">
        <?php
    }
}

/**
* Prints Out Single Post thumbnail with Schema
*/
function minimal_single_post_thumbnail(){
    if ( has_post_thumbnail() ) : ?>

            <figure>
                <?php the_post_thumbnail('full', array('class' => 'img-fluid single-post__featured-image'));?>
            </figure>
    <?php

    endif;
}

if ( ! function_exists( 'magazine_single_post_comment' ) ) {
  /**
   * Display the post header with a link to the single post
   *
   * @since 1.0.0
   */
  function magazine_single_post_comment() {
    // If comments are open or we have at least one comment, load up the comment template.
    if ( comments_open() || get_comments_number() ) :
      comments_template();
    endif;
  }
}






function minimal_comment_count(){
    if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
        echo '<span class="meta comments-link">';
        comments_popup_link( esc_html__( 'Leave a comment', 'minimal-magazine' ), esc_html__( '1 Comment', 'minimal-magazine' ), esc_html__( '% Comments', 'minimal-magazine' ) );
        echo '</span>';
    }
}






// Numbered Pagination
if ( ! function_exists( 'minimal_pagination' ) ) :
function minimal_pagination() {
  global $defaults;
  $blog_pagination_type = $defaults['minimal_blog_pagination_type'];

    if( $blog_pagination_type === 1):
        // Next & Previous Page Pagination
        echo '<div class="article-pagination-custom col-12">';
        next_posts_link('Next Page', 0);
        previous_posts_link('Previous Page', 0);
        echo '</div>';
    endif;
    if( $blog_pagination_type === 2):
        // Numeric Pagination
        echo '<div class="col-md-12">';
        echo '<div class="article-pagination-num">';
            the_posts_pagination( array(
                'prev_text' => '<i class="fa fa-long-arrow-left"></i>',
                'next_text' => '<i class="fa fa-long-arrow-right"></i>',
            ) );
        echo '</div>';
        echo '</div>';
    endif;
    if( $blog_pagination_type === 3):
        // Display Pagination using WP-PageNavi Plugin
        if ( function_exists('wp_pagenavi') ){
            wp_pagenavi();
        }
    endif;

}
endif;





function minimal_check_section_image($background_image){
        if(!empty($background_image)){
            return "background-image: url('$background_image');";
        }
}

function minimal_check_section_color($background_color){
        if(!empty($background_color)){
            return "background-color:$background_color;";
        }
}


/**
* Check & Prints out Scroll To Top if activated
*/
function minimal_scroll_to_top(){
  global $defaults;
    if($defaults['minimal_show_scroll_to_top'] == true){ ?>
  <script>
  // Scroll To Top
  jQuery(window).scroll(function(){
    if (jQuery(this).scrollTop() > 700) {
        jQuery('.scrollToTop').fadeIn();
    } else {
        jQuery('.scrollToTop').fadeOut();
    }
    });

    //Click event to scroll to top
    jQuery('.scrollToTop').click(function(){
      jQuery('html, body').animate({scrollTop : 0},1000);
            return false;
    });
    </script>
<?php }}




function minimal_category() {
    if ( 'post' === get_post_type() ) {
    /* translators: used between list items, there is a space after the comma */
    $categories_list = get_the_category_list( esc_html__( ' ', 'minimal-magazine' ) );
        if ( $categories_list && minimal_categorized_blog() ) {
            echo '<span class="meta meta-category" rel="tag">' . wp_kses_post($categories_list) . '</span>';
        }
    }
}



/**
* Returns true if a blog has more than 1 category.
*
* @return bool
*/
function minimal_categorized_blog() {
    if ( false === ( $all_the_cool_cats = get_transient( 'minimal_category' ) ) ) {
    // Create an array of all the categories that are attached to posts.
    $all_the_cool_cats = get_categories( array(
                                        'fields'     => 'ids',
                                        'hide_empty' => 1,
                                        // We only need to know if there is more than one category.
                                        'number'     => 2,
                                        )
    );
    // Count the number of categories that are attached to the posts.
    $all_the_cool_cats = count( $all_the_cool_cats );
    set_transient( 'minimal_category', $all_the_cool_cats );
    }

    if ( $all_the_cool_cats > 1 ) {
        return true;
    } else {
        return false;
    }
}


function minimal_category_transient_flusher() {
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return;
    }
    // Like, beat it. Dig?
    delete_transient( 'minimal_category' );
}



function minimal_clean_archive_title() {

  if ( is_category() ) {
      $title = single_cat_title( '', false );
  } elseif ( is_tag() ) {
      $title = single_tag_title( '', false );
  }

  return $title;
}

    // checkbox sanitization
    function aqua_sanitize_checkbox( $input ) {
        if ( $input == 1 ) {
            return 1;
        } else {
            return '';
        }
    }